package com.goldenwater.slaj.eme.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eme.domain.BusiSuppliesReserve;

/**
 * 应急物资储备 数据层
 */
@Mapper
public interface BusiSuppliesReserveMapper {

    /**
     * 查询应急物资储备
     * @param guid 查询条件
     * @return 应急物资储备
     */
    BusiSuppliesReserve selectBusiSuppliesReserveByGuid(String guid);

    /**
     * 查询应急物资储备列表
     * @param busiSuppliesReserve 查询条件
     * @return 应急物资储备集合
     */
    List<BusiSuppliesReserve> selectBusiSuppliesReserveList(BusiSuppliesReserve busiSuppliesReserve);

    /**
     * 新增应急物资储备
     * @param busiSuppliesReserve 应急物资储备
     * @return 影响行数
     */
    int insertBusiSuppliesReserve(BusiSuppliesReserve busiSuppliesReserve);

    /**
     * 修改应急物资储备
     * @param busiSuppliesReserve 应急物资储备
     * @return 影响行数
     */
    int updateBusiSuppliesReserve(BusiSuppliesReserve busiSuppliesReserve);

    /**
     * 删除应急物资储备
     * @param guid 主键
     * @return 影响行数
     */
    int deleteBusiSuppliesReserveByGuid(String guid);

    /**
     * 批量删除应急物资储备
     * @param guids 主键数组
     * @return 影响行数
     */
    int deleteBusiSuppliesReserveByGuids(String[] guids);
}
